# -*- coding: utf-8 -*-
"""AAF parsing entry point
"""
import time, sys
from os.path import join
from glob import glob
from eoleaaf import aaf

from eoleaaf.ihm import print_time
from eoleaaf.miscutil import parse_xml_files
from eoleaaf.util import db

times = [time.time()]

def main(xml_path, maj_mode, close=True):
    """parsing main entry point
    the parsing type depends on the name of the xml file
    """
    # REM: parsing order is very important for database integrity validation
    aaftypes = [{'pattern': "_EtabEducNat_", 'function': "parse_aaf_etab_educnat", 'type': 'etablissement', 'delete_function': 'delete_etab_educnat'},
                {'pattern': "_MatiereEducNat_", 'function': "parse_aaf_subjects", 'type': 'matiere', 'delete_function': 'delete_subject'},
                {'pattern': "_PersRelEleve_", 'function': "parse_aaf_responsables", 'type': 'responsable', 'delete_function': 'delete_responsables'},
                {'pattern': "_Eleve_", 'function': "parse_aaf_eleves", 'type': 'élève', 'delete_function': 'delete_eleves'},
                {'pattern': "_PersEducNat_", 'function': "parse_aaf_profs", 'type': 'administratif', 'delete_function': 'delete_profs'}
    ]

    xml_files = glob(join(xml_path, "*.xml"))
    xml_files.sort()

    # parsing etab
    aaf.maj_mode = maj_mode
    for aaftype in aaftypes:
        if aaf.maj_mode:
            delete_function = aaftype['delete_function']
        else:
            delete_function = None
        parse_xml_files(aaftype['pattern'], aaftype['function'], xml_files, aaf, delete_function)
        print_time(aaftype['type'], times)
    if close:
        db.close()

